# OpenBB Government US Provider

This extension integrates the [US Government](https://data.gov) data provider into the OpenBB Platform.

## Installation

To install the extension:

```bash
pip install openbb-us-government
```

See the OpenBB Documentation [here](https://docs.openbb.co/python/) for details on getting started.

## Coverage

This extension covers services with no registration requirement.

- `obb.commodity.psd_report`
- `obb.commodity.psd_data`
- `obb.commodity.weather_bulletins`
- `obb.commodity.weather_bulletins_download`
- `obb.fixed_income.government.treasury_auctions`
- `obb.fixed_income.government.treasury_prices`

See the [reference](https://docs.openbb.co/python/reference) for breakdowns of each endpoint.
